@@ -1,6 +1,6 @@
-;;; minted.el --- AUCTeX style for `minted.sty' (v2.5)  -*- lexical-binding: t; -*-
+;;; minted.el --- AUCTeX style for `minted.sty' (v2.9)  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2014-2018, 2020 Free Software Foundation, Inc.
+;; Copyright (C) 2014--2024 Free Software Foundation, Inc.
 
 ;; Author: Tassilo Horn <tsdh@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -10,23 +10,21 @@
 ;; This file is part of AUCTeX.
 
 ;; AUCTeX is free software; you can redistribute it and/or modify it
-;; under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3, or (at your option)
-;; any later version.
+;; under the terms of the GNU General Public License as published by the
+;; Free Software Foundation; either version 3, or (at your option) any
+;; later version.
 
-;; AUCTeX is distributed in the hope that it will be useful, but
-;; WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License for more details.
+;; AUCTeX is distributed in the hope that it will be useful, but WITHOUT
+;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+;; for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with AUCTeX; see the file COPYING.  If not, write to the Free
-;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-;; 02110-1301, USA.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
-;; This file adds support for `minted.sty' (v2.5) from 2017/07/19.
+;; This file adds support for `minted.sty' (v2.9) from 2023/12/18.
 
 ;;; Code:
 
@@ -47,13 +45,14 @@
                   "newfloat" (&rest newfloat-declarefloatingenvironments))
 
 (defvar font-latex-syntactic-keywords-extra)
+(defvar LaTeX-fontenc-package-options)
 
 (defvar LaTeX-minted-key-val-options
   '(("autogobble" ("true" "false"))
     ("baselinestretch" ("auto"))
     ("beameroverlays" ("true" "false"))
     ("breakafter")
-    ("breakaftergroup" ("true" "false"))
+    ("breakafterinrun" ("true" "false"))
     ("breakaftersymbolpre")
     ("breakaftersymbolpost")
     ("breakanywhere" ("true" "false"))
@@ -61,7 +60,7 @@
     ("breakanywheresymbolpost")
     ("breakautoindent" ("true" "false"))
     ("breakbefore")
-    ("breakbeforegroup" ("true" "false"))
+    ("breakbeforeinrun" ("true" "false"))
     ("breakbeforesymbolpre")
     ("breakbeforesymbolpost")
     ("breakbytoken" ("true" "false"))
@@ -105,6 +104,7 @@
     ("gobble")
     ("highlightcolor")
     ("highlightlines")
+    ("ignorelexererrors" ("true" "false"))
     ("keywordcase" ("lower" "upper" "capitalize"))
     ("label")
     ("labelposition" ("none" "topline" "bottomline" "all"))
@@ -130,18 +130,21 @@
     ;; `LaTeX-minted-style-list' here, but with a file local var like:
     ;;     %%% TeX-command-extra-options: "-shell-escape"
     ;; in a .tex file, Emacs asks to apply a variable which is not
-    ;; safe and does not restore the frame; the splitted frame
+    ;; safe and does not restore the window; the splitted frame
     ;; remains.  I couldn't figure out why, so for now, I add the
-    ;; styles from Pygments version 2.5.2 here.
+    ;; styles from Pygments version 2.18.0 here.
     ("style" ("abap" "algol" "algol_nu" "arduino" "autumn"
-              "borland" "bw" "colorful" "default" "emacs"
-              "friendly" "fruity" "igor" "inkpot" "lovelace"
-              "manni" "monokai" "murphy" "native" "paraiso-dark"
-              "paraiso-light" "pastie" "perldoc"
-              "rainbow_dash" "rrt" "sas"
-              "solarized-dark" "solarized-light" "stata"
-              "stata-dark" "stata-light"
-              "tango" "trac" "vim" "vs" "xcode"))
+              "bw" "borland" "coffee" "colorful" "default" "dracula"
+              "emacs" "friendly_grayscale" "friendly" "fruity"
+              "github-dark" "gruvbox-dark" "gruvbox-light"
+              "igor" "inkpot" "lightbulb" "lilypond"
+              "lovelace" "manni" "material" "monokai" "murphy"
+              "native" "nord-darker" "nord"
+              "one-dark" "paraiso-dark" "paraiso-light" "pastie"
+              "perldoc" "rainbow_dash" "rrt" "sas"
+              "solarized-dark" "solarized-light" "staroffice"
+              "stata-dark" "stata-light" "tango" "trac"
+              "vim" "vs" "xcode" "zenburn"))
     ("stepnumber")
     ("stepnumberfromfirst")
     ("stepnumberoffsetvalues" ("true" "false"))
@@ -156,14 +159,34 @@
     ("xrightmargin"))
   "Key=value options for minted macros and environments.")
 
-(defvar LaTeX-minted-key-val-options-local nil
-  "Buffer-local key=value options for minted macros and environments.")
-(make-variable-buffer-local 'LaTeX-minted-key-val-options-local)
+(defun LaTeX-minted-key-val-options ()
+  "Return an updated list of key=vals from minted package.
+This function retrieves values of (user) defined colors and
+prepends them to variable `LaTeX-minted-key-val-options'."
+  (append
+   (when (or (member "xcolor" (TeX-style-list))
+             (member "color" TeX-active-styles))
+     (let* ((colorcmd (if (member "xcolor" TeX-active-styles)
+                          #'LaTeX-xcolor-definecolor-list
+                        #'LaTeX-color-definecolor-list))
+            (colors (mapcar #'car (funcall colorcmd)))
+            (keys '("bgcolor" "highlightcolor"
+                    "rulecolor" "spacecolor" "tabcolor"))
+            result)
+       (dolist (key keys result)
+         (push (list key colors) result))))
+   LaTeX-minted-key-val-options))
 
-(defvar LaTeX-minted-pygmentize-program (executable-find "pygmentize"))
+(defvar LaTeX-minted-pygmentize-program (executable-find "pygmentize")
+  "Absolute file name to pygmentize program.")
 
 (defvar LaTeX-minted-language-list nil
-  "List containing languages provided by pymentize program.")
+  "List containing languages provided by pymentize program.
+Initialized once at the first prompt for a Pygments language.
+May be reset with `\\[universal-argument] \\[TeX-normal-mode]'.")
+
+;; Add the variable to `TeX-normal-mode-reset-list':
+(add-to-list 'TeX-normal-mode-reset-list 'LaTeX-minted-language-list)
 
 (defun LaTeX-minted-language-list (&rest _ignored)
   "Return a list of languages provided by pymentize program.
@@ -181,17 +204,13 @@ Update the variable `LaTeX-minted-language-list' if still nil."
             (setq LaTeX-minted-language-list languages))
           LaTeX-minted-language-list))))
 
-(defun LaTeX-arg-minted-language (optional &optional prompt)
-    "Insert a selected pygmentize language as argument for macros from minted.sty.
-If OPTIONAL is non-nil, insert it as optional argument in
-brackets.  PROMPT replaces the standard one."
-  (TeX-argument-insert
-   (completing-read (TeX-argument-prompt optional prompt "Language")
-                    (LaTeX-minted-language-list))
-   optional))
-
 (defvar LaTeX-minted-style-list nil
-  "List containing styles provided by pymentize program.")
+  "List containing styles provided by pymentize program.
+Initialized once at the first prompt for a Pygments style.
+May be reset with `\\[universal-argument] \\[TeX-normal-mode]'.")
+
+;; Add the variable to `TeX-normal-mode-reset-list':
+(add-to-list 'TeX-normal-mode-reset-list 'LaTeX-minted-style-list)
 
 (defun LaTeX-minted-style-list (&rest _ignored)
   "Return a list of styles provided by pymentize program.
@@ -209,131 +228,91 @@ Update the variable `LaTeX-minted-style-list' if still nil."
             (setq LaTeX-minted-style-list styles))
           LaTeX-minted-style-list))))
 
-(defun LaTeX-arg-minted-style (optional &optional prompt)
-  "Insert a selected pygmentize style as argument for macros from minted.sty.
-If OPTIONAL is non-nil, insert it as optional argument in
-brackets.  PROMPT replaces the standard one."
-  (TeX-argument-insert
-   (completing-read (TeX-argument-prompt optional prompt "Style")
-                    (LaTeX-minted-style-list))
-   optional))
+(TeX-auto-add-type "minted-newmint" "LaTeX")
 
-(defun LaTeX-minted-update-key-vals ()
-  "Update color related key-vals in `LaTeX-minted-key-val-options-local'.
-This function checks if one of the packages \"xcolor.sty\" or
-\"xcolor.sty\" is loaded and appends defined colors as values to
-color related key.  \"xcolor.sty\" is preferred if both packages
-are loaded."
-  (when (or (member "xcolor" (TeX-style-list))
-            (member "color" (TeX-style-list)))
-    (let* ((colorcmd (if (member "xcolor" (TeX-style-list))
-                         #'LaTeX-xcolor-definecolor-list
-                       #'LaTeX-color-definecolor-list))
-           (colorkeys '("bgcolor" "highlightcolor"
-                        "rulecolor" "spacecolor" "tabcolor"))
-           (opts (copy-alist LaTeX-minted-key-val-options-local)))
-      (dolist (key colorkeys)
-        (setq opts (assq-delete-all (car (assoc key opts)) opts))
-        (push (list key (mapcar #'car (funcall colorcmd)))
-              opts))
-      (setq LaTeX-minted-key-val-options-local
-            (copy-alist opts)))))
-
-(defvar LaTeX-minted-auto-newminted nil)
-(defvar LaTeX-minted-newminted-regexp
-  '("\\\\newminted\\(?:\\[\\([^]]+\\)\\]\\)?{\\([^}]+\\)}{[^}]*}"
-    (1 2) LaTeX-minted-auto-newminted))
-
-(defvar LaTeX-minted-auto-newmint nil)
 (defvar LaTeX-minted-newmint-regexp
-  '("\\\\newmint\\(?:\\[\\([^]]+\\)\\]\\)?{\\([^}]+\\)}{[^}]*}"
-    (1 2) LaTeX-minted-auto-newmint))
-
-(defvar LaTeX-minted-auto-newmintinline nil)
-(defvar LaTeX-minted-newmintinline-regexp
-  '("\\\\newmintinline\\(?:\\[\\([^]]+\\)\\]\\)?{\\([^}]+\\)}{[^}]*}"
-    (1 2) LaTeX-minted-auto-newmintinline))
-
-(defvar LaTeX-minted-auto-newmintedfile nil)
-(defvar LaTeX-minted-newmintedfile-regexp
-  '("\\\\newmintedfile\\(?:\\[\\([^]]+\\)\\]\\)?{\\([^}]+\\)}{[^}]*}"
-    (1 2) LaTeX-minted-auto-newmintedfile))
+  '("\\\\newmint\\(edfile\\|inline\\|ed\\)?\\(?:\\[\\([^]]+\\)\\]\\)?{\\([^}]+\\)}"
+    (2 3 1) LaTeX-auto-minted-newmint)
+  "Match the arguments of \\newmint* macros from minted package.")
 
 (defun LaTeX-minted-auto-prepare ()
-  (setq LaTeX-minted-auto-newminted     nil
-        LaTeX-minted-auto-newmint       nil
-        LaTeX-minted-auto-newmintinline nil
-        LaTeX-minted-auto-newmintedfile nil
-        LaTeX-minted-language-list      nil
-        LaTeX-minted-style-list         nil))
+  "Reset `LaTeX-auto-minted-newmint' before parsing."
+  (setq LaTeX-auto-minted-newmint nil))
 
 (defun LaTeX-minted-auto-cleanup ()
-  ;; \newminted{lang}{opts} => new langcode and langcode* envs.
-  ;; \newminted[envname]{lang}{opts} => new envname/envname* envs.
-  (dolist (name-lang LaTeX-minted-auto-newminted)
-    (let* ((env (if (> (length (car name-lang)) 0)
-                    (car name-lang)
-                  (concat (cadr name-lang) "code")))
-           (env* (concat env "*")))
-      (add-to-list 'LaTeX-auto-environment (list env))
-      (add-to-list 'LaTeX-auto-environment
-                   (list env* #'LaTeX-env-args
-                         '(TeX-arg-key-val LaTeX-minted-key-val-options-local)))
-      (add-to-list 'LaTeX-indent-environment-list `(,env current-indentation) t)
-      (add-to-list 'LaTeX-indent-environment-list `(,env* current-indentation) t)
-      (add-to-list 'LaTeX-verbatim-environments-local env)
-      (add-to-list 'LaTeX-verbatim-environments-local env*)))
-  ;; \newmint{foo}{opts} => \foo[key=vals]|code|
-  ;; \newmint[macname]{foo}{opts} => \macname[key=vals]|code|
-  (dolist (name-lang LaTeX-minted-auto-newmint)
-    (let ((lang (if (> (length (car name-lang)) 0)
-                    (car name-lang)
-                  (cadr name-lang))))
-      (add-to-list 'TeX-auto-symbol
-                   `(,lang [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
-                           TeX-arg-verb))
-      (add-to-list 'LaTeX-verbatim-macros-with-delims-local lang)
-      (when (and (fboundp 'font-latex-add-keywords)
-                 (eq TeX-install-font-lock 'font-latex-setup))
-        (font-latex-add-keywords `((,lang "[")) 'textual))))
-  ;; \newmintinline{foo}{opts} => \fooinline[key=vals]|code| or
-  ;;                              \fooinline[key=vals]{code}
-  ;; \newmintinline[macname]{foo}{opts} => \macname[key=vals]|code| or
-  ;;                                       \macname[key=vals]{code}
-  (dolist (name-lang LaTeX-minted-auto-newmintinline)
-    (let ((lang (if (> (length (car name-lang)) 0)
-                    (car name-lang)
-                  (concat (cadr name-lang) "inline"))))
-      (add-to-list 'TeX-auto-symbol
-                   `(,lang [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
-                           TeX-arg-verb-delim-or-brace))
-      (add-to-list 'LaTeX-verbatim-macros-with-delims-local lang)
-      (add-to-list 'LaTeX-verbatim-macros-with-braces-local lang)
-      (when (and (fboundp 'font-latex-add-keywords)
-                 (eq TeX-install-font-lock 'font-latex-setup))
-        (font-latex-add-keywords `((,lang "[")) 'textual))))
-  ;; \newmintedfile{foo}{opts} => \foofile[key=vals]{file-name}
-  ;; \newmintedfile[macname]{foo}{opts} => \macname[key=vals]{file-name}
-  (dolist (name-lang LaTeX-minted-auto-newmintedfile)
-    (let ((lang (if (> (length (car name-lang)) 0)
-                    (car name-lang)
-                  (concat (cadr name-lang) "file"))))
-      (add-to-list 'TeX-auto-symbol
-                   `(,lang [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
-                           TeX-arg-file))))
-  (when (and (fboundp 'font-latex-set-syntactic-keywords)
+  "Process the parsed results from minted package."
+  (dolist (mint (LaTeX-minted-newmint-list))
+    (cond ((string= (nth 2 mint) "ed")
+           ;; \newminted{lang}{opts} => new langcode and langcode* envs.
+           ;; \newminted[envname]{lang}{opts} => new envname/envname* envs.
+           (let* ((env (if (string-empty-p (car mint))
+                           (concat (cadr mint) "code")
+                         (car mint)))
+                  (env* (concat env "*")))
+             (LaTeX-add-environments (list env))
+             (LaTeX-add-environments (list env* #'LaTeX-env-args
+                                           '(TeX-arg-key-val
+                                             (LaTeX-minted-key-val-options))))
+             (add-to-list 'LaTeX-indent-environment-list
+                          `(,env current-indentation) t)
+             (add-to-list 'LaTeX-indent-environment-list
+                          `(,env* current-indentation) t)
+             (add-to-list 'LaTeX-verbatim-environments-local env)
+             (add-to-list 'LaTeX-verbatim-environments-local env*)))
+          ;; \newmintinline{foo}{opts} => \fooinline[key=vals]|code| or
+          ;;                              \fooinline[key=vals]{code}
+          ;; \newmintinline[macname]{foo}{opts} => \macname[key=vals]|code| or
+          ;;                                       \macname[key=vals]{code}
+          ((string= (nth 2 mint) "inline")
+           (let ((lang (if (string-empty-p (car mint))
+                           (concat (cadr mint) "inline")
+                         (car mint))))
+             (TeX-add-symbols `(,lang
+                                [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+                                TeX-arg-verb-delim-or-brace))
+             (add-to-list 'LaTeX-verbatim-macros-with-delims-local lang)
+             (add-to-list 'LaTeX-verbatim-macros-with-braces-local lang)
+             (when (and (fboundp 'font-latex-add-keywords)
+                        (eq TeX-install-font-lock 'font-latex-setup))
+               (font-latex-add-keywords `((,lang "[")) 'textual))))
+          ;; \newmintedfile{foo}{opts} => \foofile[key=vals]{file-name}
+          ;; \newmintedfile[macname]{foo}{opts} => \macname[key=vals]{file-name}
+          ((string= (nth 2 mint) "edfile")
+           (let ((lang (if (string-empty-p (car mint))
+                           (concat (cadr mint) "file")
+                         (car mint))))
+             (TeX-add-symbols `(,lang
+                                [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+                                TeX-arg-file))))
+          ;; \newmint{foo}{opts} => \foo[key=vals]|code| or
+          ;;                        \foo[key=vals]{code}
+          ;; \newmint[macname]{foo}{opts} => \macname[key=vals]|code| or
+          ;;                                 \macname[key=vals]{code}
+          (t
+           (let ((lang (if (string-empty-p (car mint))
+                           (cadr mint)
+                         (car mint))))
+             (TeX-add-symbols `(,lang
+                                [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+                                TeX-arg-verb-delim-or-brace))
+             (add-to-list 'LaTeX-verbatim-macros-with-delims-local lang)
+             (add-to-list 'LaTeX-verbatim-macros-with-braces-local lang)
+             (when (and (fboundp 'font-latex-add-keywords)
+                        (eq TeX-install-font-lock 'font-latex-setup))
+               (font-latex-add-keywords `((,lang "[")) 'textual))))))
+  ;; Refresh font-locking so that the verbatim envs take effect only
+  ;; when there are defined shortcuts:
+  (when (and (LaTeX-minted-newmint-list)
+             (fboundp 'font-latex-set-syntactic-keywords)
              (eq TeX-install-font-lock 'font-latex-setup))
-    ;; Refresh font-locking so that the verbatim envs take effect.
-    (font-latex-set-syntactic-keywords))
-  ;; Also update the key=vals
-  (LaTeX-minted-update-key-vals))
+    (font-latex-set-syntactic-keywords)))
 
 (add-hook 'TeX-auto-prepare-hook #'LaTeX-minted-auto-prepare t)
 (add-hook 'TeX-auto-cleanup-hook #'LaTeX-minted-auto-cleanup t)
 (add-hook 'TeX-update-style-hook #'TeX-auto-parse t)
 
 (defun LaTeX-minted-add-syntactic-keywords-extra (type macro)
-  "Add MACRO from minted.sty to `font-latex-syntactic-keywords-extra'.
+  "Add TYPE of MACRO to `font-latex-syntactic-keywords-extra'.
 TYPE is one of the symbols `brace' or `delim' indicating how
 verbatim text is enclosed after the macro.  MACRO is a string or
 a list of strings."
@@ -376,46 +355,53 @@ a list of strings."
  "minted"
  (lambda ()
 
-   ;; Activate local-version of key=vals
-   (setq LaTeX-minted-key-val-options-local
-         (copy-alist LaTeX-minted-key-val-options))
+   ;; Run the relevant style hooks:
+   (TeX-run-style-hooks "xcolor" "fvextra")
 
    ;; New symbols
    (TeX-add-symbols
     '("mint"
-      [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
-      LaTeX-arg-minted-language TeX-arg-verb)
+      [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+      (TeX-arg-completing-read (LaTeX-minted-language-list) "Language")
+      TeX-arg-verb-delim-or-brace)
     '("mintinline"
-      [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
-      LaTeX-arg-minted-language TeX-arg-verb-delim-or-brace)
-    '("newminted" ["Environment Name"] LaTeX-arg-minted-language
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
-    '("newmint" ["Macro Name"] LaTeX-arg-minted-language
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
-    '("newmintinline" ["Macro Name"] LaTeX-arg-minted-language
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
-    '("newmintedfile" ["Macro Name"] LaTeX-arg-minted-language
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
+      [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+      (TeX-arg-completing-read (LaTeX-minted-language-list) "Language")
+      TeX-arg-verb-delim-or-brace)
+    '("newminted" ["Environment Name"]
+      (TeX-arg-completing-read (LaTeX-minted-language-list) "Language")
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
+    '("newmint" ["Macro Name"]
+      (TeX-arg-completing-read (LaTeX-minted-language-list) "Language")
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
+    '("newmintinline" ["Macro Name"]
+      (TeX-arg-completing-read (LaTeX-minted-language-list) "Language")
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
+    '("newmintedfile" ["Macro Name"]
+      (TeX-arg-completing-read (LaTeX-minted-language-list) "Language")
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
     ;; 3.3 Formatting source code
     '("inputminted"
-      [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
-      (LaTeX-arg-minted-language)
+      [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+      (TeX-arg-completing-read (LaTeX-minted-language-list) "Language")
       TeX-arg-file)
     ;; 3.4 Using different styles
     '("usemintedstyle"
-      [ LaTeX-arg-minted-language ] LaTeX-arg-minted-style)
+      [TeX-arg-completing-read (LaTeX-minted-language-list) "Language"]
+      (TeX-arg-completing-read (LaTeX-minted-style-list) "Style"))
     ;; 5.2 Macro option usage
     '("setminted"
-      [ LaTeX-arg-minted-language ]
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
+      [TeX-arg-completing-read (LaTeX-minted-language-list) "Language"]
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
     '("setmintedinline"
-      [ LaTeX-arg-minted-language ]
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local)))
+      [TeX-arg-completing-read (LaTeX-minted-language-list) "Language"]
+      (TeX-arg-key-val (LaTeX-minted-key-val-options))))
 
    ;; New environments
    (LaTeX-add-environments
-    '("minted" LaTeX-env-args [TeX-arg-key-val LaTeX-minted-key-val-options-local]
-      LaTeX-arg-minted-language))
+    '("minted" LaTeX-env-args
+      [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+      (TeX-arg-completing-read (LaTeX-minted-language-list) "Language")))
 
    ;; 4 Floating listings: If option "newfloat" is given, run the
    ;; style hook and use the interface provided by the style,
@@ -438,10 +424,7 @@ a list of strings."
         '(("listing" ?l "lst:" "~\\ref{%s}" caption nil nil)))))
 
    ;; Add to the auto parser
-   (TeX-auto-add-regexp LaTeX-minted-newminted-regexp)
    (TeX-auto-add-regexp LaTeX-minted-newmint-regexp)
-   (TeX-auto-add-regexp LaTeX-minted-newmintinline-regexp)
-   (TeX-auto-add-regexp LaTeX-minted-newmintedfile-regexp)
 
    ;; Filling
    (add-to-list (make-local-variable 'LaTeX-indent-environment-list)
@@ -475,12 +458,28 @@ a list of strings."
      (font-latex-set-syntactic-keywords)))
  TeX-dialect)
 
-(defvar LaTeX-minted-package-options '("chapter"     "cache"
-                                       "cachedir"    "finalizecache"
-                                       "frozencache" "draft"
-                                       "final"       "kpsewhich"
-                                       "langlinenos" "newfloat"
-                                       "outputdir"   "section")
-  "Package options for the minted package.")
+(defun LaTeX-minted-package-options-list ()
+  "Return an alist of package options for minted package."
+  (append
+   `(("fontencoding"
+      ,(when (member "fontenc" (TeX-style-list))
+         LaTeX-fontenc-package-options)))
+   '(("chapter")
+     ("cache"            ("true" "false"))
+     ("cachedir")
+     ("finalizecache"    ("true" "false"))
+     ("frozencache"      ("true" "false"))
+     ("draft"            ("true" "false"))
+     ("final"            ("true" "false"))
+     ("inputlanglinenos" ("true" "false"))
+     ("kpsewhich"        ("true" "false"))
+     ("langlinenos"      ("true" "false"))
+     ("newfloat"         ("true" "false"))
+     ("outputdir")
+     ("section"))))
+
+(defun LaTeX-minted-package-options ()
+  "Prompt for package options for the minted package."
+  (TeX-read-key-val t (LaTeX-minted-package-options-list)))
 
 ;;; minted.el ends here
