@@ -1,6 +1,6 @@
 ;;; pythontex.el --- AUCTeX style for `pythontex.sty' (v0.16)  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2018, 2020 Free Software Foundation, Inc.
+;; Copyright (C) 2018--2023 Free Software Foundation, Inc.
 
 ;; Author: Arash Esbati <arash@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -10,19 +10,17 @@
 ;; This file is part of AUCTeX.
 
 ;; AUCTeX is free software; you can redistribute it and/or modify it
-;; under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3, or (at your option)
-;; any later version.
+;; under the terms of the GNU General Public License as published by the
+;; Free Software Foundation; either version 3, or (at your option) any
+;; later version.
 
-;; AUCTeX is distributed in the hope that it will be useful, but
-;; WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License for more details.
+;; AUCTeX is distributed in the hope that it will be useful, but WITHOUT
+;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+;; for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with AUCTeX; see the file COPYING.  If not, write to the Free
-;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-;; 02110-1301, USA.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -35,9 +33,10 @@
 (require 'latex)
 
 ;; Silence the compiler:
-;; `LaTeX-fancyvrb-key-val-options-local' will be defined after
+
+;; The function `LaTeX-fancyvrb-key-val-options' will be defined after
 ;; loading `fvextra.el' which loads `fancyvrb.el' in return:
-(defvar LaTeX-fancyvrb-key-val-options-local)
+(declare-function LaTeX-fancyvrb-key-val-options "fancyvrb" ())
 
 ;; These are provided by `font-latex.el':
 (defvar font-latex-syntactic-keywords-extra)
@@ -112,24 +111,6 @@ Update the variable `LaTeX-pythontex-language-list' if still nil."
   '("py" "sympy" "pylab" "rb" "ruby" "jl" "julia" "octave")
   "List of language families provided by pythontex package.")
 
-(defun LaTeX-env-pythontex (environment)
-  "Insert ENVIRONMENT provided by pythontex package."
-  (let ((session (TeX-read-string
-                  (TeX-argument-prompt t nil "Session")))
-        (fvkeyval (TeX-read-key-val t LaTeX-fancyvrb-key-val-options-local)))
-    (LaTeX-insert-environment environment
-                              (concat
-                               (when (and session (not (string= session "")))
-                                 (concat LaTeX-optop session LaTeX-optcl))
-                               ;; We need an extra pair of brackets
-                               ;; when no session is given but
-                               ;; key=vals are available
-                               (when (and session (string= session "")
-                                          fvkeyval (not (string= fvkeyval "")))
-                                 (concat LaTeX-optop LaTeX-optcl))
-                               (when (and fvkeyval (not (string= fvkeyval "")))
-                                 (concat LaTeX-optop fvkeyval LaTeX-optcl))))))
-
 ;; Setup for \saveprintpythontex & \savestdoutpythontex &
 ;; \savestderrpythontex
 (TeX-auto-add-type "pythontex-savecontent" "LaTeX")
@@ -247,7 +228,9 @@ a list of strings."
                     verb-macs))
      (apply #'LaTeX-add-environments
             (mapcar (lambda (env)
-                      (list env #'LaTeX-env-pythontex))
+                      (list env #'LaTeX-env-args
+                            [ "Session" ]
+                            [TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)]))
                     verb-envs))
      ;; Filling:
      (dolist (mac verb-macs)
@@ -293,175 +276,126 @@ a list of strings."
     ;; 4.2.5 Custom code
     ;; pythontexcustomc[<position>]{<family>}{<code>}
     '("pythontexcustomc"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Position")
-        '("begin" "end") ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Family")
-                    LaTeX-pythontex-family-list)
+      [TeX-arg-completing-read ("begin" "end") "Position"]
+      (TeX-arg-completing-read LaTeX-pythontex-family-list "Family")
       t)
 
     ;; 4.2.7 Formatting of typeset code
     ;; \setpythontexfv[<family>]{<fancyvrb settings>}
     '("setpythontexfv"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Family")
-        LaTeX-pythontex-family-list ]
-      (TeX-arg-key-val LaTeX-fancyvrb-key-val-options-local))
+      [TeX-arg-completing-read LaTeX-pythontex-family-list "Family"]
+      (TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)))
 
     ;; \setpythontexprettyprinter[<family>]{<printer>}
-    '("setpythontexprettyprinter"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Family")
-        (cons "auto" LaTeX-pythontex-family-list) ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Printer")
-                    '("text" "bw" "fancyvrb" "pygments")))
+    `("setpythontexprettyprinter"
+      [TeX-arg-completing-read ,(lambda ()
+                                  (cons "auto" LaTeX-pythontex-family-list))
+                               "Family"]
+      (TeX-arg-completing-read ("text" "bw" "fancyvrb" "pygments") "Printer"))
 
     ;; \setpythontexpyglexer[<family>]{<pygments lexer>}
     '("setpythontexpyglexer"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Family")
-        LaTeX-pythontex-family-list ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Pygments lexer")
-                    (LaTeX-pythontex-language-list)))
+      [TeX-arg-completing-read LaTeX-pythontex-family-list "Family"]
+      (TeX-arg-completing-read (LaTeX-pythontex-language-list) "Pygments lexer"))
 
     ;; \setpythontexpygopt[<family>]{<pygments options>}
     '("setpythontexpygopt"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Family")
-        LaTeX-pythontex-family-list ]
-      (TeX-arg-key-val
-       (("style") ("texcomments") ("mathescape"))))
+      [TeX-arg-completing-read LaTeX-pythontex-family-list "Family"]
+      (TeX-arg-key-val (("style") ("texcomments") ("mathescape"))))
 
     ;; 4.2.8 Access to printed content (stdout)
     ;; \printpythontex[<mode>][<options>]
     '("printpythontex"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Mode")
-        '("raw" "verb" "verbatim") ]
-      [ TeX-arg-key-val LaTeX-fancyvrb-key-val-options-local ] )
+      [TeX-arg-completing-read ("raw" "verb" "verbatim") "Mode"]
+      [TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)])
 
     ;; \stdoutpythontex[<mode>][<options>]
     '("stdoutpythontex"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Mode")
-        '("raw" "verb" "verbatim") ]
-      [ TeX-arg-key-val LaTeX-fancyvrb-key-val-options-local ] )
+      [TeX-arg-completing-read ("raw" "verb" "verbatim") "Mode"]
+      [TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)])
 
     ;;\saveprintpythontex{<name>}
     '("saveprintpythontex"
-      (TeX-arg-eval (lambda ()
-                      (let ((name (TeX-read-string
-                                   (TeX-argument-prompt nil nil "Name"))))
-                        (LaTeX-add-pythontex-savecontents name)
-                        (format "%s" name)))))
+      (lambda (optional)
+        (let ((name (TeX-read-string
+                     (TeX-argument-prompt optional nil "Name"))))
+          (LaTeX-add-pythontex-savecontents name)
+          (TeX-argument-insert name optional))))
 
     ;;\savestdoutpythontex{<name>}
     '("savestdoutpythontex"
-      (TeX-arg-eval (lambda ()
-                      (let ((name (TeX-read-string
-                                   (TeX-argument-prompt nil nil "Name"))))
-                        (LaTeX-add-pythontex-savecontents name)
-                        (format "%s" name)))))
+      (lambda (optional)
+        (let ((name (TeX-read-string
+                     (TeX-argument-prompt optional nil "Name"))))
+          (LaTeX-add-pythontex-savecontents name)
+          (TeX-argument-insert name optional))))
 
     ;; \useprintpythontex[<verbatim options>][<fancyvrb options>]{<name>}
     ;; I assume <verbatim options> is meant to be <mode>
     '("useprintpythontex"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Mode")
-        '("raw" "verb" "verbatim") ]
-      [ TeX-arg-key-val LaTeX-fancyvrb-key-val-options-local ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Name")
-                    (LaTeX-pythontex-savecontent-list)))
+      [TeX-arg-completing-read ("raw" "verb" "verbatim") "Mode"]
+      [TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)]
+      (TeX-arg-completing-read (LaTeX-pythontex-savecontent-list) "Name"))
 
     ;; \usestdoutpythontex[<verbatim options>][<fancyvrb options>]{<name>}
     ;; I assume <verbatim options> is meant to be <mode>
     '("usestdoutpythontex"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Mode")
-        '("raw" "verb" "verbatim") ]
-      [ TeX-arg-key-val LaTeX-fancyvrb-key-val-options-local ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Name")
-                    (LaTeX-pythontex-savecontent-list)))
+      [TeX-arg-completing-read ("raw" "verb" "verbatim") "Mode"]
+      [TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)]
+      (TeX-arg-completing-read (LaTeX-pythontex-savecontent-list) "Name"))
 
     ;; \stderrpythontex[<mode>][<fancyvrb options>]
     '("stderrpythontex"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Mode")
-        '("raw" "verb" "verbatim") ]
-      [ TeX-arg-key-val LaTeX-fancyvrb-key-val-options-local ] )
-
+      [TeX-arg-completing-read ("raw" "verb" "verbatim") "Mode"]
+      [TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)])
 
     ;;\savestderrpythontex{<name>}
     '("savestderrpythontex"
-      (TeX-arg-eval (lambda ()
-                      (let ((name (TeX-read-string
-                                   (TeX-argument-prompt nil nil "Name"))))
-                        (LaTeX-add-pythontex-savecontents name)
-                        (format "%s" name)))))
+      (lambda (optional)
+        (let ((name (TeX-read-string
+                     (TeX-argument-prompt optional nil "Name"))))
+          (LaTeX-add-pythontex-savecontents name)
+          (TeX-argument-insert name optional))))
 
     ;; \usestderrpythontex[<mode>][<fancyvrb options>]{<name>}
     '("usestderrpythontex"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Mode")
-        '("raw" "verb" "verbatim") ]
-      [ TeX-arg-key-val LaTeX-fancyvrb-key-val-options-local ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Name")
-                    (LaTeX-pythontex-savecontent-list)))
+      [TeX-arg-completing-read ("raw" "verb" "verbatim") "Mode"]
+      [TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)]
+      (TeX-arg-completing-read (LaTeX-pythontex-savecontent-list) "Name"))
 
     ;;\setpythontexautoprint{<boolean>}
     '("setpythontexautoprint"
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Boolean value")
-                    '("true" "false")))
+      (TeX-arg-completing-read ("true" "false") "Boolean value"))
 
     ;; \setpythontexautostdout{<boolean>}
     '("setpythontexautostdout"
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Boolean value")
-                    '("true" "false")))
+      (TeX-arg-completing-read ("true" "false") "Boolean value"))
 
     ;; 4.3 Pygments commands and environments
     ;; \pygment{<lexer>}<opening delim><code><closing delim>
     '("pygment"
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Lexer")
-                    (LaTeX-pythontex-language-list))
+      (TeX-arg-completing-read (LaTeX-pythontex-language-list) "Lexer")
       TeX-arg-verb-delim-or-brace)
 
     ;; \inputpygments[<fancyvrb settings>]{<lexer>}{<external file>}
     '("inputpygments"
-      [ TeX-arg-eval LaTeX-fancyvrb-key-val-options-local ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Lexer")
-                    (LaTeX-pythontex-language-list))
+      [TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)]
+      (TeX-arg-completing-read (LaTeX-pythontex-language-list) "Lexer")
       TeX-arg-file-name)
 
     ;; \setpygmentsfv[<lexer>]{<fancyvrb settings>}
     '("setpygmentsfv"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Lexer")
-        (LaTeX-pythontex-language-list) ]
-      (TeX-arg-eval LaTeX-fancyvrb-key-val-options-local))
+      [TeX-arg-completing-read (LaTeX-pythontex-language-list) "Lexer"]
+      (TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)))
 
     ;; \setpygmentspygopt[<lexer>]{<pygments options>}
     '("setpygmentspygopt"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Lexer")
-        (LaTeX-pythontex-language-list) ]
-      (TeX-arg-key-val
-       (("style") ("texcomments") ("mathescape"))))
+      [TeX-arg-completing-read (LaTeX-pythontex-language-list) "Lexer"]
+      (TeX-arg-key-val (("style") ("texcomments") ("mathescape"))))
 
     ;; \setpygmentsprettyprinter{<printer>}
     '("setpygmentsprettyprinter"
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Printer")
-                    '("text" "bw" "fancyvrb" "pygments")))
+      (TeX-arg-completing-read ("text" "bw" "fancyvrb" "pygments") "Printer"))
 
     ;; 4.5  Advanced PythonTeX usage
     ;; \setpythontexcontext{<key-value pairs>}
@@ -491,30 +425,23 @@ a list of strings."
    ;; Cater for \setpythontexlistingenv:
    (TeX-add-symbols
     '("setpythontexlistingenv"
-      (TeX-arg-eval
-       (lambda ()
-         (let ((name (TeX-read-string
-                      (TeX-argument-prompt nil nil "Listing environment name"))))
-           (LaTeX-add-newfloat-DeclareFloatingEnvironments `(,name "verbatim"))
-           (LaTeX-newfloat-auto-cleanup)
-           (format "%s" name))))))
+      (lambda (optional)
+        (let ((name (TeX-read-string
+                     (TeX-argument-prompt optional nil "Listing environment name"))))
+          (LaTeX-add-newfloat-DeclareFloatingEnvironments `(,name "verbatim"))
+          (LaTeX-newfloat-auto-cleanup)
+          (TeX-argument-insert name optional)))))
 
    (LaTeX-add-environments
     ;; 4.2.5 Custom code
     '("pythontexcustomcode" LaTeX-env-args
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Position")
-        '("begin" "end") ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Family")
-                    LaTeX-pythontex-family-list))
+      [TeX-arg-completing-read ("begin" "end") "Position"]
+      (TeX-arg-completing-read LaTeX-pythontex-family-list "Family"))
 
     ;; \begin{pygments}[<fancyvrb settings>]{<lexer>}
     '("pygments" LaTeX-env-args
-      [ TeX-arg-eval LaTeX-fancyvrb-key-val-options-local ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Lexer")
-                    (LaTeX-pythontex-language-list))) )
+      [TeX-arg-key-val (LaTeX-fancyvrb-key-val-options)]
+      (TeX-arg-completing-read (LaTeX-pythontex-language-list) "Lexer")))
 
    ;; Filling
    (add-to-list 'LaTeX-indent-environment-list
