@@ -1,4 +1,4 @@
-;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v12.4.0)  -*- lexical-binding: t; -*-
+;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v13.4.0)  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2023--2024 Free Software Foundation, Inc.
 
@@ -10,24 +10,22 @@
 ;; This file is part of AUCTeX.
 
 ;; AUCTeX is free software; you can redistribute it and/or modify it
-;; under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3, or (at your option)
-;; any later version.
+;; under the terms of the GNU General Public License as published by the
+;; Free Software Foundation; either version 3, or (at your option) any
+;; later version.
 
-;; AUCTeX is distributed in the hope that it will be useful, but
-;; WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License for more details.
+;; AUCTeX is distributed in the hope that it will be useful, but WITHOUT
+;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+;; for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with AUCTeX; see the file COPYING.  If not, write to the Free
-;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-;; 02110-1301, USA.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
-;; This file adds support for `simpleicons.sty' (v12.4.0) from
-;; 2024/06/28.  `simpleicons.sty' is part of TeXLive.
+;; This file adds support for `simpleicons.sty' (v13.4.0) from
+;; 2024/08/09.  `simpleicons.sty' is part of TeXLive.
 
 ;;; Code:
 
@@ -341,11 +339,6 @@
     "awssecretsmanager"
     "awwwards"
     "axios"
-    "azureartifacts"
-    "azuredataexplorer"
-    "azuredevops"
-    "azurefunctions"
-    "azurepipelines"
     "babel"
     "babelio"
     "babylondotjs"
@@ -551,6 +544,7 @@
     "chocolatey"
     "chromatic"
     "chromecast"
+    "chromewebstore"
     "chrysler"
     "chupachups"
     "cilium"
@@ -699,7 +693,6 @@
     "cryengine"
     "cryptpad"
     "crystal"
-    "csharp"
     "css3"
     "cssdesignawards"
     "cssmodules"
@@ -720,7 +713,6 @@
     "daf"
     "dailydotdev"
     "dailymotion"
-    "daimler"
     "daisyui"
     "dapr"
     "darkreader"
@@ -738,7 +730,6 @@
     "datagrip"
     "dataiku"
     "datastax"
-    "dataverse"
     "datefns"
     "datev"
     "datocms"
@@ -772,7 +763,6 @@
     "dependencycheck"
     "depositphotos"
     "derspiegel"
-    "designernews"
     "deutschebahn"
     "deutschebank"
     "deutschepost"
@@ -810,7 +800,6 @@
     "docsify"
     "doctrine"
     "docusaurus"
-    "docusign"
     "dogecoin"
     "doi"
     "dolby"
@@ -847,7 +836,6 @@
     "dvc"
     "dwavesystems"
     "dwm"
-    "dynamics365"
     "dynatrace"
     "e"
     "e3"
@@ -1127,6 +1115,7 @@
     "glitch"
     "globus"
     "glovo"
+    "gltf"
     "gmail"
     "gnome"
     "gnometerminal"
@@ -1175,7 +1164,6 @@
     "googledatastudio"
     "googledisplayandvideo360"
     "googledocs"
-    "googledomains"
     "googledrive"
     "googleearth"
     "googleearthengine"
@@ -1183,7 +1171,6 @@
     "googlefonts"
     "googleforms"
     "googlegemini"
-    "googlehangouts"
     "googlehome"
     "googlekeep"
     "googlelens"
@@ -1191,14 +1178,11 @@
     "googlemarketingplatform"
     "googlemeet"
     "googlemessages"
-    "googlemybusiness"
     "googlenearby"
     "googlenews"
-    "googleoptimize"
     "googlepay"
     "googlephotos"
     "googleplay"
-    "googlepodcasts"
     "googlepubsub"
     "googlescholar"
     "googlesearchconsole"
@@ -1344,9 +1328,6 @@
     "iata"
     "ibeacon"
     "iberia"
-    "ibm"
-    "ibmcloud"
-    "ibmwatson"
     "iced"
     "iceland"
     "icicibank"
@@ -1411,7 +1392,6 @@
     "intermarche"
     "internetarchive"
     "internetcomputer"
-    "internetexplorer"
     "intigriti"
     "intuit"
     "invision"
@@ -1541,6 +1521,7 @@
     "koc"
     "kodak"
     "kodi"
+    "koenigsegg"
     "kofax"
     "kofi"
     "komoot"
@@ -1641,12 +1622,14 @@
     "listmonk"
     "lit"
     "litecoin"
+    "literal"
     "litiengine"
     "livechat"
     "livejournal"
     "livewire"
     "llvm"
     "lmms"
+    "lobsters"
     "local"
     "lodash"
     "logitech"
@@ -1768,25 +1751,6 @@
     "microeditor"
     "microgenetics"
     "micropython"
-    "microsoft"
-    "microsoftacademic"
-    "microsoftaccess"
-    "microsoftazure"
-    "microsoftbing"
-    "microsoftedge"
-    "microsoftexcel"
-    "microsoftexchange"
-    "microsoftonedrive"
-    "microsoftonenote"
-    "microsoftoutlook"
-    "microsoftpowerpoint"
-    "microsoftsharepoint"
-    "microsoftsqlserver"
-    "microsoftstore"
-    "microsoftteams"
-    "microsofttranslator"
-    "microsoftvisio"
-    "microsoftword"
     "microstation"
     "microstrategy"
     "midi"
@@ -1795,8 +1759,8 @@
     "milanote"
     "milvus"
     "minds"
-    "minecraft"
     "minetest"
+    "mingww64"
     "mini"
     "minio"
     "mintlify"
@@ -1818,7 +1782,6 @@
     "modin"
     "modrinth"
     "modx"
-    "mojangstudios"
     "moleculer"
     "momenteo"
     "monero"
@@ -1836,6 +1799,7 @@
     "moo"
     "moodle"
     "moonrepo"
+    "moq"
     "moqups"
     "morrisons"
     "moscowmetro"
@@ -2037,6 +2001,7 @@
     "orcid"
     "oreilly"
     "org"
+    "organicmaps"
     "origin"
     "osano"
     "osf"
@@ -2045,6 +2010,7 @@
     "osmc"
     "osu"
     "otto"
+    "outline"
     "overcast"
     "overleaf"
     "ovh"
@@ -2162,8 +2128,8 @@
     "playstation3"
     "playstation4"
     "playstation5"
+    "playstationportable"
     "playstationvita"
-    "playwright"
     "pleroma"
     "plesk"
     "plex"
@@ -2203,14 +2169,7 @@
     "posthog"
     "postman"
     "postmates"
-    "powerapps"
-    "powerautomate"
-    "powerbi"
-    "powerfx"
-    "powerpages"
     "powers"
-    "powershell"
-    "powervirtualagents"
     "prdotco"
     "preact"
     "precommit"
@@ -2367,6 +2326,7 @@
     "redis"
     "redmine"
     "redox"
+    "redsys"
     "redux"
     "reduxsaga"
     "redwoodjs"
@@ -2380,7 +2340,7 @@
     "removedotbg"
     "renault"
     "render"
-    "renovatebot"
+    "renovate"
     "renpy"
     "renren"
     "replit"
@@ -2583,8 +2543,6 @@
     "skoda"
     "sky"
     "skypack"
-    "skype"
-    "skypeforbusiness"
     "skyrock"
     "slack"
     "slackware"
@@ -2795,6 +2753,7 @@
     "teamcity"
     "teamspeak"
     "teamviewer"
+    "techcrunch"
     "ted"
     "teepublic"
     "teespring"
@@ -2971,6 +2930,7 @@
     "unitedairlines"
     "unitednations"
     "unity"
+    "unjs"
     "unlicense"
     "unocss"
     "unpkg"
@@ -3034,10 +2994,6 @@
     "virtualbox"
     "virustotal"
     "visa"
-    "visualbasic"
-    "visualstudio"
-    "visualstudioappcenter"
-    "visualstudiocode"
     "visx"
     "vite"
     "vitepress"
@@ -3100,6 +3056,7 @@
     "webex"
     "webflow"
     "webgl"
+    "webgpu"
     "weblate"
     "webmin"
     "webmoney"
@@ -3133,11 +3090,6 @@
     "wikiquote"
     "wikivoyage"
     "winamp"
-    "windows"
-    "windows10"
-    "windows95"
-    "windowsterminal"
-    "windowsxp"
     "wipro"
     "wire"
     "wireguard"
@@ -3166,10 +3118,7 @@
     "wykop"
     "wyze"
     "x"
-    "xamarin"
-    "xaml"
     "xampp"
-    "xbox"
     "xcode"
     "xdadevelopers"
     "xdotorg"
@@ -3189,7 +3138,6 @@
     "yamahacorporation"
     "yamahamotorcorporation"
     "yaml"
-    "yammer"
     "yandexcloud"
     "yarn"
     "ycombinator"
@@ -3227,6 +3175,7 @@
     "zenodo"
     "zensar"
     "zerodha"
+    "zerotier"
     "zerply"
     "zettlr"
     "zhihu"
