@@ -10,19 +10,17 @@
 ;; This file is part of AUCTeX.
 
 ;; AUCTeX is free software; you can redistribute it and/or modify it
-;; under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3, or (at your option)
-;; any later version.
+;; under the terms of the GNU General Public License as published by the
+;; Free Software Foundation; either version 3, or (at your option) any
+;; later version.
 
-;; AUCTeX is distributed in the hope that it will be useful, but
-;; WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License for more details.
+;; AUCTeX is distributed in the hope that it will be useful, but WITHOUT
+;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+;; for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with AUCTeX; see the file COPYING.  If not, write to the Free
-;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-;; 02110-1301, USA.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -43,19 +41,22 @@
 
 ;;; Code:
 
-(eval-when-compile
-  (require 'cl-lib))
-
 (require 'tex)
 (autoload 'LaTeX-forward-paragraph "latex")
 (autoload 'LaTeX-backward-paragraph "latex")
 (autoload 'LaTeX-find-matching-begin "latex")
 (autoload 'LaTeX-find-matching-end "latex")
+(autoload 'LaTeX-mark-section "latex")
 (autoload 'ConTeXt-find-matching-start "context")
 (autoload 'ConTeXt-find-matching-stop "context")
 (autoload 'Texinfo-find-env-start "tex-info")
 (autoload 'Texinfo-find-env-end "tex-info")
 
+;; Silence the compiler
+(declare-function LaTeX-verbatim-macro-boundaries "latex")
+(declare-function LaTeX-verbatim-macros-with-braces "latex")
+(declare-function LaTeX-verbatim-macros-with-delims "latex")
+
 (defgroup TeX-fold nil
   "Fold TeX macros."
   :group 'AUCTeX)
@@ -245,15 +246,62 @@ After that, changing the prefix key requires manipulating keymaps."
     (define-key map "\C-b" #'TeX-fold-buffer)
     (define-key map "\C-r" #'TeX-fold-region)
     (define-key map "\C-p" #'TeX-fold-paragraph)
+    (define-key map "\C-s" #'TeX-fold-section)
     (define-key map "\C-m" #'TeX-fold-macro)
     (define-key map "\C-e" #'TeX-fold-env)
     (define-key map "\C-c" #'TeX-fold-comment)
     (define-key map "b"    #'TeX-fold-clearout-buffer)
     (define-key map "r"    #'TeX-fold-clearout-region)
     (define-key map "p"    #'TeX-fold-clearout-paragraph)
+    (define-key map "s"    #'TeX-fold-clearout-section)
     (define-key map "i"    #'TeX-fold-clearout-item)
     map))
 
+(defcustom TeX-fold-auto-reveal-commands
+  '((key-binding [left])
+    (key-binding [right])
+    backward-char
+    forward-char
+    mouse-set-point
+    pop-to-mark-command
+    undo)
+  "List of commands that may cause a fold to be revealed.
+This list is consulted by the default value of `TeX-fold-auto-reveal'."
+  :type '(repeat (choice (function :tag "Function")
+                         (sexp :tag "Key binding"))))
+
+(defcustom TeX-fold-auto-reveal
+  '(eval . ((apply #'TeX-fold-arrived-via
+                   (mapcar (lambda (cmd)
+                             (if (and (listp cmd) (eq (car cmd) 'key-binding))
+                                 (eval cmd t)
+                               cmd))
+                           TeX-fold-auto-reveal-commands))
+            t))
+  "Predicate to open a fold when entered.
+Possibilities are:
+t autoopens,
+nil doesn't,
+a symbol will have its value consulted if it exists,
+defaulting to nil if it doesn't.
+A CONS-cell means to call a function for determining the value.
+The CAR of the cell is the function to call which receives
+the CDR of the CONS-cell in the rest of the arguments, while
+point and current buffer point to the position in question.
+All of the options show reasonable defaults."
+  :group 'TeX-fold
+  :type '(choice (const :tag "Off" nil)
+                 (const :tag "On" t)
+                 (symbol :tag "Indirect variable" :value reveal-mode)
+                 (cons :tag "Function call"
+                       :value (eval (TeX-fold-arrived-via
+                                     (key-binding [left])
+                                     (key-binding [right])
+                                     #'backward-char #'forward-char
+                                     #'mouse-set-point))
+                       function (list :tag "Argument list"
+                                      (repeat :inline t sexp)))))
+
 
 ;;; Folding
 
@@ -296,6 +344,66 @@ and `TeX-fold-math-spec-list', and environments in `TeX-fold-env-spec-list'."
       (TeX-fold-clearout-region start end)
       (TeX-fold-region start end))))
 
+(defun TeX-fold-section ()
+  "Hide all configured macros and environments in the current section.
+The relevant macros are specified in the variable `TeX-fold-macro-spec-list'
+and `TeX-fold-math-spec-list', and environments in `TeX-fold-env-spec-list'."
+  (interactive)
+  (save-mark-and-excursion
+    (LaTeX-mark-section)
+    (let ((start (point))
+          (end (mark)))
+      (TeX-fold-clearout-region start end)
+      (TeX-fold-region start end))))
+
+(defcustom TeX-fold-region-functions '(TeX-fold-verbs)
+  "List of additional functions to call when folding a region.
+Each function is called with two arguments, the start and end positions
+of the region to fold."
+  :type '(repeat function)
+  :package-version '(auctex . "14.0.7"))
+
+(defun TeX-fold--verb-data (&rest _args)
+  "Return data describing verbatim macro at point.
+Returns list of the form (START END CONTENT).  This should be called
+only in LaTeX modes."
+  (when-let* ((boundaries (LaTeX-verbatim-macro-boundaries))
+              (bound-start (car boundaries))
+              (bound-end (cdr boundaries))
+              (end-delim-char (char-before bound-end))
+              (start-delim-char (if (= end-delim-char ?\})
+                                    ?\{
+                                  end-delim-char))
+              (start-delim (char-to-string start-delim-char))
+              (verb-arg-start
+               (1+ (progn
+                     (goto-char bound-end)
+                     (if (string= start-delim TeX-grop)
+                         (progn (backward-sexp) (point))
+                       (forward-char -1)
+                       (search-backward start-delim bound-start t)))))
+              (verb-arg-end (1- bound-end)))
+    (list bound-start
+          bound-end
+          (buffer-substring verb-arg-start verb-arg-end))))
+
+(defun TeX-fold-verbs (start end)
+  "In LaTeX modes, fold verbatim macros between START and END."
+  (when (derived-mode-p 'LaTeX-mode)
+    (save-excursion
+      (goto-char start)
+      (let ((re (concat (regexp-quote TeX-esc)
+                        (regexp-opt
+                         (append
+                          (LaTeX-verbatim-macros-with-braces)
+                          (LaTeX-verbatim-macros-with-delims))))))
+        (while (let ((case-fold-search nil))
+                 (re-search-forward re end t))
+          (when-let* ((data (TeX-fold--verb-data))
+                      (spec (lambda (&rest _args)
+                              (nth 2 (TeX-fold--verb-data)))))
+            (apply #'TeX-fold--make-misc-overlay (append data (list spec)))))))))
+
 (defun TeX-fold-region (start end)
   "Fold all items in region from START to END."
   (interactive "r")
@@ -307,7 +415,8 @@ and `TeX-fold-math-spec-list', and environments in `TeX-fold-env-spec-list'."
   (when (memq 'math TeX-fold-type-list)
     (TeX-fold-region-macro-or-env start end 'math))
   (when (memq 'comment TeX-fold-type-list)
-    (TeX-fold-region-comment start end)))
+    (TeX-fold-region-comment start end))
+  (run-hook-with-args 'TeX-fold-region-functions start end))
 
 (defun TeX-fold-region-macro-or-env (start end type)
   "Fold all items of type TYPE in region from START to END.
@@ -524,6 +633,25 @@ See its doc string for detail."
     (overlay-put ov 'TeX-fold-display-string-spec display-string-spec)
     ov))
 
+(defun TeX-fold--make-misc-overlay (start end display-string display-string-spec)
+  "Create a miscellaneous overlay between START and END.
+DISPLAY-STRING is the display string, while DISPLAY-STRING-SPEC is as in
+`TeX-fold-make-overlay'.
+
+This function is intended to be used with verbatim environments and
+other miscellaneous folding constructs.  By contrast, the function
+`TeX-fold-make-overlay' is used in the implementation of
+`TeX-fold-hide-item', which applies to typical macros, environments and
+math."
+  (let ((priority (TeX-overlay-prioritize start end))
+        (ov (make-overlay start end)))
+    (overlay-put ov 'category 'TeX-fold)
+    (overlay-put ov 'priority priority)
+    (overlay-put ov 'evaporate t)
+    (overlay-put ov 'display display-string)
+    (overlay-put ov 'TeX-fold-display-string-spec display-string-spec)
+    ov))
+
 (defun TeX-fold-item-end (start type)
   "Return the end of an item of type TYPE starting at START.
 TYPE can be either `env' for environments, `macro' for macros or
@@ -600,11 +728,26 @@ backward compatibility and always nil."
                                          (concat open-string " \t"))
                                         (point)))
                   (goto-char
-                   (if delims
-                       (with-syntax-table
-                           (TeX-search-syntax-table open-char close-char)
-                         (scan-lists (point) 1 1))
-                     (TeX-find-closing-brace)))
+                   (if (save-restriction
+                         (widen)
+                         ;; `widen' accomodates the following issue:
+                         ;; with point on the `v' in `\end{verbatim}',
+                         ;; LaTeX-verbatim-p returns nil normally, but t
+                         ;; with region narrowed to avoid the
+                         ;; corresponding `\begin{verbatim}'.
+                         (TeX-verbatim-p))
+                       (cond ((derived-mode-p 'LaTeX-mode)
+                              (cdr (LaTeX-verbatim-macro-boundaries)))
+                             ;; FIXME: When other modes implement a
+                             ;; nontrivial `TeX-verbatim-p-function', we
+                             ;; should return the appropriate endpoint
+                             ;; here.
+                             )
+                     (if delims
+                         (with-syntax-table
+                             (TeX-search-syntax-table open-char close-char)
+                           (scan-lists (point) 1 1))
+                       (TeX-find-closing-brace))))
                   (setq content-end (save-excursion
                                       (backward-char)
                                       (skip-chars-backward " \t")
@@ -707,6 +850,15 @@ breaks will be replaced by spaces."
           (start (progn (LaTeX-backward-paragraph) (point))))
       (TeX-fold-clearout-region start end))))
 
+(defun TeX-fold-clearout-section ()
+  "Permanently show all macros in the section point is located in."
+  (interactive)
+  (save-mark-and-excursion
+    (LaTeX-mark-section)
+    (let ((start (point))
+          (end (mark)))
+      (TeX-fold-clearout-region start end))))
+
 (defun TeX-fold-clearout-region (start end)
   "Permanently show all macros in region starting at START and ending at END."
   (interactive "r")
@@ -781,7 +933,9 @@ That means, put respective properties onto overlay OV."
                            (setq arg-list (append arg-list (list (car arg)))))
                          (setq n (1+ n)))
                        (or (condition-case nil
-                               (apply spec arg-list)
+                               (save-excursion
+                                 (goto-char ov-start)
+                                 (apply spec arg-list))
                              (error nil))
                            "[Error: No content or function found]")))
                     (t (or (TeX-fold-macro-nth-arg spec ov-start ov-end)
@@ -833,6 +987,22 @@ Remove the respective properties from the overlay OV."
   (when font-lock-mode
     (overlay-put ov 'face TeX-fold-unfolded-face)))
 
+(defun TeX-fold-auto-reveal-p (mode)
+  "Decide whether to auto-reveal.
+Return non-nil if folded region should be auto-opened.
+See `TeX-fold-auto-reveal' for definitions of MODE."
+  (cond ((symbolp mode)
+         (and (boundp mode)
+              (symbol-value mode)))
+        ((consp mode)
+         (apply (car mode) (cdr mode)))
+        (t mode)))
+
+(defun TeX-fold-arrived-via (&rest list)
+  "Indicate auto-opening.
+Return non-nil if called by one of the commands in LIST."
+  (memq this-command list))
+
 ;; Copy and adaption of `reveal-post-command' from reveal.el in GNU
 ;; Emacs on 2004-07-04.
 (defun TeX-fold-post-command ()
@@ -855,14 +1025,10 @@ Remove the respective properties from the overlay OV."
               (setq TeX-fold-open-spots (cdr spots))
               (when (or disable-point-adjustment
                         global-disable-point-adjustment
-                        ;; See preview.el on how to make this configurable.
-                        (memq this-command
-                              (list (key-binding [left]) (key-binding [right])
-                                    #'backward-char #'forward-char
-                                    #'mouse-set-point)))
+                        (TeX-fold-auto-reveal-p TeX-fold-auto-reveal))
                 ;; Open new overlays.
                 (dolist (ol (nconc (when (and TeX-fold-unfold-around-mark
-                                              mark-active)
+                                              (TeX-active-mark))
                                      (overlays-at (mark)))
                                    (overlays-at (point))))
                   (when (eq (overlay-get ol 'category) 'TeX-fold)
